@@ -34,7 +34,7 @@ my $s = Data::Serializer::Sereal->new();
 my %CACHE_COMMON = (
   driver         => 'FastMmap',
   root_dir       => $cache_root->stringify,
-  expires_in     => '30m',
+  expires_in     => '5h',
   cache_size     => '15m',
   key_serializer => $s,
   serializer     => $s,
